#include <stdint.h>


typedef struct {
  uint16_t		vendorid;
  uint16_t		deviceid;
  int		chipreg;
  const char	*name;
} AthlonChips_s;

typedef struct {
  const char	*desc;
  int		addr;
  uint32_t		bit;
} EachReg_s;

typedef struct {
  int		regid;
  int		tp;
  EachReg_s	regs[3];
} ChipReg_s;

/* VendorID, DeviceID, ChipReg number, Name strings */
static AthlonChips_s AthlonChips[] = {
  /* AMD chipset ---------------------------------------------------------*/
  /* AMD 751 */
  { 0x1022, 0x7006, 0x00, "AMD-751" },
  { 0x1022, 0x700E, 0x00, "AMD-761" },
  { 0x1022, 0x700C, 0x01, "AMD-762" },
  /* VIA Chipset --------------------------------------------------------*/
  /* VIA VT8371 */
  { 0x1106, 0x0391, 0x10, "VIA KX133" },
  { 0x1106, 0x0691, 0x10, "VIA KX133" },
  /* VIA VT8361 */
  { 0x1106, 0x3112, 0x10, "VIA KLE133" },
  /* VIA VT8363/8365/8364/8362[A] */
  { 0x1106, 0x0305, 0x10, "VIA KT133/KM133/KL133/KN133[A] series" },
  /* VIA VT8366 */
  { 0x1106, 0x3099, 0x11, "VIA KT266/333[A] series" },
  /* VIA VT8375 */
  { 0x1106, 0x3116, 0x11, "VIA KM266" },
  { 0x1106, 0x3156, 0x11, "VIA P/KN266" },
  /* VIA VT8368 */
  { 0x1106, 0x3189, 0x12, "VIA KT400[A]" },
  /* VIA VT8378 */
  { 0x1106, 0x3205, 0x12, "VIA KM400[A]" },
  /* SiS Chipset ----------------------------------------------------------*/
  /* SiS 730/733 */
  { 0x1039, 0x0730, 0x20, "SiS 730" },
  { 0x1039, 0x0733, 0x20, "SiS 733" },
  /* SiS 735 or later */
  { 0x1039, 0x0735, 0x21, "SiS 735" },
  { 0x1039, 0x0740, 0x21, "SiS 740" },
  { 0x1039, 0x0745, 0x21, "SiS 745" },
  { 0x1039, 0x0755, 0x21, "SiS 755" },
  /* SiS 746 or later */
  { 0x1039, 0x0746, 0x22, "SiS 746[FX]" },
  { 0x1039, 0x0748, 0x22, "SiS 748" },
  /* nVIDIA chipset -----------------------------------------------------*/
  /* nForce */
  { 0x10de, 0x01a4, 0x30, "nVIDIA nForce series" },
  /* nForce2 */
  { 0x10de, 0x01e0, 0x31, "nVIDIA nForce2" },
  /* End Mark */
  { 0, 0, 0, NULL }
};

static ChipReg_s ChipReg[] = {
  /* AMD chipset ----------------------------------------------------------*/
  /* AMD AMD-751/761 */
  { 0x00, LONG,
    { {"Halt Disconnect and Stop Grant Disconnect", 0x60, 0x00060000},
      {NULL, 0, 0 } } },
  /* AMD AMD-762 (Chipset has not support HALT disconnect,
     so Powersaving only enables when S1 or S3 state entered */
  { 0x01, LONG, { {"Stop Grant Disconnect #0", 0x60, 0x00020000},
		  {"Stop Grant Disconnect #1", 0x68, 0x00020000},
		  {NULL, 0, 0 } } },
  /* VIA Chipset ---------------------------------------------------------*/
  /* VIA KX/KLE/KT/KM/KL/KN133[A] */
  { 0x10, BYTE, { {"bus Disconnect when STPGNT detected", 0x52, 0x80},
		  {NULL, 0, 0 } } },
  /* VIA KT/KM/266/333[A] */
  { 0x11, BYTE, { {"bus Disconnect when STPGNT detected", 0x92, 0x80},
		  {"VLink Auto-disconnect", 0x95, 0x02},
		  {NULL, 0, 0 } } },
   /* VIA VT8368 */
  { 0x12, BYTE, { {"bus Disconnect when STPGNT detected", 0xD2, 0x80},
		  {"VLink Auto-disconnect", 0xD5, 0x02},
		  {NULL, 0, 0 } } },
  /* SiS Chipset ---------------------------------------------------------*/
  /* SiS 730/733 */
  { 0x20, BYTE, { {"bus Disconnect when STPGNT detected", 0x6B, 0x01},
		  {NULL, 0, 0 } } },
  /* SiS 735/740/745/755 */
  { 0x21, SHORT, { {"bus Disconnect when STPGNT detected", 0x6A, 0x0001},
		   {NULL, 0, 0 } } },
  /* SiS 746 or later */
  { 0x22, SHORT, { {"bus Disconnect when STPGNT detected", 0x6C, 0x0001},
		   {NULL, 0, 0 } } },
  /* nVIDIA chipset -----------------------------------------------------*/
  /* nForce */
  { 0x30, SHORT, { /* {"Self-reflesh enable", 0x6C, 0x8000}, */
		  {"Halt Disconnect and Stop Grant Disconnect",
		   0xE6, 0x0600 },
		  {NULL, 0, 0 } } },
  /* nForce2 */
  { 0x31, BYTE, { {"Halt Disconnect and Stop Grant Disconnect", 0x6F, 0x10}, 
		  {NULL, 0, 0 } } },
  /* end mark */
  { 0, 0, { {NULL, 0, 0} } }
};
/* End Of File	**************************************************************/
